@@ -17,6 +17,15 @@ var assignOperatorScenarios = []expressionScenario{
 			"D0, P[], ()::a:\n    b: cat\nx: frog\n",
 		},
 	},
+	{
+		description: "Create yaml file",
+		document:    "a: {b: 3}",
+		expression:  `.a |= .`,
+		skipDoc:     true,
+		expected: []string{
+			"D0, P[], (!!map)::a: {b: 3}\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		document:   "{}",
