@@ -35,6 +35,15 @@ steps:
 `
 
 var traversePathOperatorScenarios = []expressionScenario{
+	{
+		skipDoc:     true,
+		description: "strange map with key but no value",
+		document:    "!!null\n-",
+		expression:  ".x",
+		expected: []string{
+			"D0, P[x], (!!null)::null\n",
+		},
+	},
 	{
 		skipDoc:     true,
 		description: "access merge anchors",
