@@ -1,11 +1,24 @@
 #!/bin/bash
-set -e
-# you may need to go install github.com/mitchellh/gox@v1.0.1 first
-echo $VERSION
-CGO_ENABLED=0 gox -ldflags "-s -w ${LDFLAGS}" -output="build/yq_{{.OS}}_{{.Arch}}" --osarch="darwin/amd64 darwin/arm64 freebsd/386 freebsd/amd64 freebsd/arm linux/386 linux/amd64 linux/arm linux/arm64 linux/mips linux/mips64 linux/mips64le linux/mipsle linux/ppc64 linux/ppc64le linux/s390x netbsd/386 netbsd/amd64 netbsd/arm openbsd/386 openbsd/amd64 windows/386 windows/amd64"
+
+set -eo pipefail
+
+# You may need to go install github.com/goreleaser/goreleaser/v2@latest first
+GORELEASER="goreleaser build --clean"
+if [ -z "$CI" ]; then
+  GORELEASER+=" --snapshot"
+fi
+
+mkdir -p build
+
+$GORELEASER
+
+cp yq.1 build/yq.1
 
 cd build
 
+# Remove artifacts from goreleaser
+rm artifacts.json config.yaml metadata.json
+
 find . -executable -type f | xargs -I {} tar czvf {}.tar.gz {} yq.1 -C ../scripts install-man-page.sh
 tar czvf yq_man_page_only.tar.gz yq.1 -C ../scripts install-man-page.sh
 
